#!/usr/bin/env monkeyrunner
# Copyright 2010, The Android Open Source Project
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from com.android.monkeyrunner import MonkeyRunner as mr

import os
import sys

supported_formats = ['html', 'text', 'sdk-docs']

if len(sys.argv) != 3:
  print 'help.py: format output'
  sys.exit(1)

(format, saveto_path) = sys.argv[1:]

if not format.lower() in supported_formats:
  print 'format %s is not a supported format' % format
  sys.exit(2)

output = mr.help(format=format)
if not output:
  print 'Error generating help format'
  sys.exit(3)

dirname = os.path.dirname(saveto_path)
try:
    os.makedirs(dirname)
except:
    print 'oops'
    pass # It already existed

fp = open(saveto_path, 'w')
fp.write(output)
fp.close()

sys.exit(0)



#!/usr/bin/env monkeyrunner
# Copyright 2010, The Android Open Source Project
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import com.android.monkeyrunner.MonkeyRunnerHelp as mrh
import pydoc
import sys

def create_page(title, document):
  return """
page.title=%s
@jd:body
%s
</body>
</html>
""" % (title, document)

BASEDIR = 'frameworks/base/docs/html/guide/topics/testing/'

def main():
  document = ""

  for clz in mrh.getAllDocumentedClasses():
    object, name = pydoc.resolve(str(clz), 0)
    document += pydoc.html.document(object, name)

  page = create_page('MonkeyRunner API', document)
  file = open(BASEDIR + 'monkeyrunner_api.html', 'w')
  file.write(page)
  file.close()

if __name__ == '__main__':
  main()



#!/usr/bin/python2.4
#
# Copyright 2010, The Android Open Source Project
#
# Licensed under the Apache License, Version 2.0 (the 'License');
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Test cases for com.android.monkeyrunner.MonkeyRunner."""

import time
import unittest

from com.android.monkeyrunner import MonkeyRunner


class TestMonkeyRunnerArgParsing(unittest.TestCase):
  """Test ArgParsing for the MonkeyRunner methods."""
  def testWaitForConnectionNoArgs(self):
    MonkeyRunner.waitForConnection()

  def testWaitForConnectionSingleArg(self):
    MonkeyRunner.waitForConnection(2)

  def testWaitForConnectionDoubleArg(self):
    MonkeyRunner.waitForConnection(2, '*')

  def testWaitForConnectionKeywordArg(self):
    MonkeyRunner.waitForConnection(timeout=2, deviceId='foo')

  def testWaitForConnectionKeywordArgTooMany(self):
    try:
      MonkeyRunner.waitForConnection(timeout=2, deviceId='foo', extra='fail')
    except TypeError:
      return
    self.fail('Should have raised TypeError')

  def testSleep(self):
    start = time.time()
    MonkeyRunner.sleep(1.5)
    end = time.time()

    self.assertTrue(end - start >= 1.5)

if __name__ == '__main__':
  unittest.main()



#!/usr/bin/python2.4
#
# Copyright 2010, The Android Open Source Project
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Test runner to run all the tests in this package."""

import os
import re
import sys
import unittest


TESTCASE_RE = re.compile('_test\.py$')


def AllTestFilesInDir(path):
  """Finds all the unit test files in the given path."""
  return filter(TESTCASE_RE.search, os.listdir(path))


def suite(loader=unittest.defaultTestLoader):
  """Creates the all_tests TestSuite."""
  script_parent_path = os.path.abspath(os.path.dirname(sys.argv[0]))
  # Find all the _test.py files in the same directory we are in
  test_files = AllTestFilesInDir(script_parent_path)
  # Convert them into module names
  module_names = [os.path.splitext(f)[0] for f in test_files]
  # And import them
  modules = map(__import__, module_names)
  # And create the test suite for all these modules
  return unittest.TestSuite([loader.loadTestsFromModule(m) for m in modules])

if __name__ == '__main__':
  result = unittest.TextTestRunner().run(suite())
  if not result.wasSuccessful():
    # On failure return an error code
    sys.exit(1)
